package com.fastbee.rechargecard.mapper;

import java.util.List;
import com.fastbee.rechargecard.domain.NgIrrigationArea;

/**
 * 灌区Mapper接口
 *
 * @author kerwincui
 * @date 2024-12-26
 */
public interface NgIrrigationAreaMapper
{
    /**
     * 查询灌区
     *
     * @param id 灌区主键
     * @return 灌区
     */
    public NgIrrigationArea selectNgIrrigationAreaById(Long id);

    /**
     * 查询灌区列表
     *
     * @param ngIrrigationArea 灌区
     * @return 灌区集合
     */
    public List<NgIrrigationArea> selectNgIrrigationAreaList(NgIrrigationArea ngIrrigationArea);

    /**
     * 新增灌区
     *
     * @param ngIrrigationArea 灌区
     * @return 结果
     */
    public int insertNgIrrigationArea(NgIrrigationArea ngIrrigationArea);

    /**
     * 修改灌区
     *
     * @param ngIrrigationArea 灌区
     * @return 结果
     */
    public int updateNgIrrigationArea(NgIrrigationArea ngIrrigationArea);

    /**
     * 删除灌区
     *
     * @param id 灌区主键
     * @return 结果
     */
    public int deleteNgIrrigationAreaById(Long id);

    /**
     * 批量删除灌区
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteNgIrrigationAreaByIds(Long[] ids);
}
